---
title: Rapport lignes de champ électrique
author: Gawen Ackermann et Florian Burgener
---

# Rapport sur la création d'une simulation de lignes de champ électrique

<center>Gawen Ackermann et Florian Burgener</center>

## Introduction

Le but de ce travail est de créer une simulation permettant de visualiser le phénomène physique du champ électrique entre plusieurs particules chargées. Plus précisément, ce travail permet d'observer le comportement des lignes de champ par rapport à des particules chargées positivement ou négativement, placé arbitrairement dans un univers discrétisé. Ci-dessous, vous pouvez observer l'application de la théorie du champ électrique entre deux charges, pour la partie de gauche, les deux particules sont chargées positivement et ont la même charge et sur la partie de droite les particules sont également de même charge, cependant la première est chargée négativement tandis que le deuxième est chargée positivement. Nous devrions arriver à un résultat similaire avec notre simulation.

![](assets/introduction_electrical_field.png)

<center>Figure 1 - Résultat que l'on devrait obtenir avec cette simulation (si même configuration)</center>

Ce rapport se décompose en trois parties, la première partie est une explication de la théorie physique du champ électrique ainsi que des formules que nous avons utilisé pour créer cette simulation, la deuxième partie est une description détaillée de la façon dont nous avons appliqué la théorie ainsi qu'une argumentation sur la réussite de l'objectif, la dernière partie est une synthèse de ce travail ainsi qu'une réflexion sur les différentes possibilités d'améliorations que nous pourrions apporter à celui-ci.

## Théorie

### Formules de physique

Un champ électrique est un champ qui entoure des particules chargées électriquement, il exerce une force sur toutes les autres particules chargées à l'intérieur de celui-ci ce qui a pour effet d'attirer ou de repousser les particules. La formule du champ électrique découle d'une transformation de la loi de Coulomb.

**Loi de Coulomb :**
$$
F = \frac{1}{4\pi\epsilon_0} \cdot \frac{\lvert q_0q_1 \rvert}{r^2} = K\frac{\lvert q_0q_1 \rvert}{r^2}
$$
où K est la constante de Coulomb $K = \frac{1}{4\pi\epsilon_0}$, $\epsilon_0$ étant la valeur de la permittivité du vide.

Cette loi représente la force exercée entre deux particules chargées. La variable $r$ est la distance qui sépare les deux particules chargées.

La direction de la force appliquée sur la particule 0 est le vecteur unitaire allant de la particule 0 à la particule 1, si et seulement si, les deux particules ont un signe différent (par exemple, la particule 0 est chargée positivement et la particule 1 est chargée négativement). Pour obtenir la direction de la force appliquée sur la particule 1, il faut changer la particule 0 par la particule 1 et la particule 1 par la particule 0 (pour la particule 1, la direction de la force est le vecteur unitaire allant de la particule 1 à la particule 0).

Dans le même principe, si les deux particules ont le même signe (par exemple, les deux particules sont chargées positivement) la force va dans la direction opposée, pour la force appliquée sur la particule 0, la direction de la force est l'opposé du vecteur unitaire allant de la particule 0 à la particule 1. Pour la particule 1, il faut changer la particule 0 par la particule 1 et la particule 1 par la particule 0 (de la même façon que précédemment).

**Loi du champ électrique :**
$$
E = \frac{F}{q_0} = K\frac{\lvert q_0q_1 \rvert}{r^2} \cdot \frac{1}{q_0} = K\frac{\lvert q_1 \rvert}{r^2}
$$
Il est important de noter que $q_0$ (la charge d'essai) est toujours une charge positive ayant une charge beaucoup moins importante que $q_1$ afin qu'elle ne perturbe pas le champ électrique. Cette formule est le résultat de l'annulation de $q_0$ dans la loi de Coulomb. Le champ électrique n'étant dépendant que de la particule $q_1$, alors la direction de celui-ci à la position de $q_0$ va de la particule $q_0$ à $q_1$, si la particule $q_1$ est chargée négativement et va dans la direction opposée, si la particule $q_1$ est chargé positivement.

**Principe de superposition du champ électrique :**
$$
E = \frac{F_1}{q_0} + \frac{F_2}{q_0} + \frac{F_3}{q_0} + \cdots
\\
E = K\frac{\lvert q_1 \rvert}{r_1^2} + K\frac{\lvert q_2 \rvert}{r_2^2} + K\frac{\lvert q_3 \rvert}{r_3^2} + \cdots
\\
E = E_1 + E_2 + E_3 + \cdots
$$
Le champ électrique résultant en un point $p$ est la somme des champs électriques. Par exemple, si on a deux particules et un point $p$, alors le champ électrique au point $p$ est le champ électrique entre le point $p$ et la particule 1 additionné au champ électrique entre le point $p$ et la particule 2.

### Description de l'algorithme de dessin d'une ligne de champ

Afin de pouvoir dessiner les lignes de champ des diverses charges présentent dans l'univers, nous avons utilisé une boucle infinie que nous allons stopper dans certaines conditions. Le point d'origine d'une ligne de champ est choisi aléatoirement dans l'univers.

On commence d'abord par calculer le point suivant avec le point courant (il faut utiliser le point d'origine lors de la première itération) et le champ électrique en ce point. Lors du calcul du champ électrique, si la norme de la distance entre le champ électrique et la charge est inférieure à une valeur arbitraire, alors la fonction qui s'occupe de ce calcul retourne faux, ce qui nous permet de savoir qu'il faut quitter la boucle car on considère que le point est trop proche de la particule.

Dans un second temps, on vérifie que le point suivant se situe bel et bien dans l'univers, s'il n'y est pas on arrête le dessin de la ligne de champ car le bord de l'univers a été atteint. Finalement, on dessine une ligne entre le point courant et le nouveau point, puis on recommence depuis le début en modifiant la valeur du point courant par la valeur du point suivant.

La ligne de champ est dessinée dans un sens puis dans l'autre, car sinon nous n'obtenons que la moitié de la ligne ! Les formules ci-dessous décrivent la façon dont le point suivant est calculé, la première formule permet de dessiner la ligne de champ dans un sens et la seconde formule dans l'autre.

$$
P_{suivant} = P_{courant} + \delta x \cdot \frac{\vec{E}}{\lvert\lvert \vec{E} \rvert\rvert}\\
P_{suivant} = P_{courant} - \delta x \cdot \frac{\vec{E}}{\lvert\lvert \vec{E} \rvert\rvert}
$$

où $\vec{E}$ est le champ électrique au point $P_{courant}$.

La variable $\delta x$ ci-dessus est calculé de la manière suivante :
$$
\delta x = \frac{1}{\sqrt[]{{width} \cdot {height}}}
$$
où ${width}$ et ${height}$ correspondant à la largeur et hauteur de la fenêtre.

## Résultats

Dans cette partie, nous allons détailler comment nous sommes arrivés à créer notre simulation de lignes de champ et pourquoi nous pensons que notre résultat est une bonne représentation du phénomène physique. Nous allons commencer par quelques explications concernant la définition de la simulation. Cette dernière existe seulement dans un univers de taille ${[}0,1{]} \times {[}0,1{]}$, si nous affichons cet univers sur un écran le point $\begin{pmatrix} 0 \\ 0 \end{pmatrix}$ est en haut à gauche et le point $\begin{pmatrix} 1 \\ 1 \end{pmatrix}$ se situe en bas à droite. Tout ce qui pourrait exister en dehors de cette limite n'est pas calculé et par conséquent ni affiché.

Avant de discuter du résultat de la simulation, parlons d'abord des algorithmes que nous avons implémenté pour le dessin des lignes et le dessin des cercles. La fonction `gfx_draw_circle` dans notre code est une implémentation de [l'algorithme de tracé d'arc de cercle de Bresenham](https://fr.wikipedia.org/wiki/Algorithme_de_trac%C3%A9_d%27arc_de_cercle_de_Bresenham). En ce qui concerne le dessin de ligne notre fonction `gfx_draw_line` est une implémentation de [l'algorithme de tracé de segment de Bresenham](https://fr.wikipedia.org/wiki/Algorithme_de_trac%C3%A9_de_segment_de_Bresenham). À noter que ce dernier est très performant car il n'utilise pas de nombres flottants.

Nous allons maintenant démontrer que notre simulation est fidèle au phénomène physique du champ électrique. Ci-dessous, vous pouvez observer le résultat de notre simulation avec deux particules. La première particule est chargée négativement (d'une fois la charge élémentaire) et placée à la position $x=0.25$ et $y=0.5$, la deuxième particule est chargée positivement (d'une fois la charge élémentaire) et placée à la position $x=0.75$ et $y=0.5$.

| Résultat souhaité                         | Résultat obtenu                           |
| :---------------------------------------: | :---------------------------------------: |
| ![](assets/results_simulation_pred_0.png) | ![](assets/results_simulation_result.png) |

En comparant l'image décrivant la théorie et le résultat de notre simulation, on observe que celle-ci ce comporte comme prédite. Cependant, nous allons créer deux configurations différentes supplémentaires afin de nous assurer que notre simulation est représentative du phénomène physique et cohérente par rapport à la théorie.

Afin de pouvoir valider notre simulation, nous avons utilisé ce site internet https://alienkevin.github.io/electric-fields/ qui nous permet de créer des prédictions et de les comparer à notre simulation. Ci-dessous se trouve notre résultat que vous comparez à la prédiction.

|                         Prédiction                          |                     Notre simulation                     |
| :---------------------------------------------------------: | :------------------------------------------------------: |
| Prédiction 1<br />![](assets/results_simulation_pred_1.png) | Résultat 1<br />![](assets/results_simulation_res_1.png) |
| Prédiction 2<br />![](assets/results_simulation_pred_2.png) | Résultat 2<br />![](assets/results_simulation_res_2.png) |

Ces deux cas ci-dessus étant beaucoup plus complexes que le résultat initial souhaité, s'ils sont justes, démontre que notre simulation l'est probablement aussi avec une haute certitude. Si l'on compare attentivement la prédiction 1 (celle-ci générée par le site) et le résultat 1 (celui de notre simulation) on voit qu'ils sont quasiment similaires et pareillement pour la deuxième situation. À ce stade nous concluons que notre simulation correspond bel et bien au modèle physique des lignes du champ électrique.

## Conclusion

L'objectif de ce travail était de réaliser une simulation de lignes de champ électrique. Pour y arriver, nous avons utilisé la formule du champ électrique qui est une transformation de loi de Coulomb et nous avons également créé un algorithme permettant d'effectuer le dessin des lignes de champ en fonction de plusieurs charges placées aléatoirement dans un univers discrétisé.

Nous avons démontré par le biais de divers exemples dans la partie "Résultats" de ce rapport que notre simulation est fidèle au phénomène physique du champ électrique.

Bien évidemment, ce travail peut-être amélioré de diverses manières et nous allons décrire ci-après 3 améliorations que nous aimerions lui apporter. La première amélioration serait l'ajout du déplacement des particules en temps réel. Les particules devraient s'attirer et se répulser comme dans la réalité et nous devrions pouvoir observer l'évolution des lignes de champ. La deuxième amélioration serait l'affichage de flèches directionnelles sur les lignes de champ qui indiqueraient leur direction comme sur la figure 1 dans l'introduction de ce rapport. La dernière amélioration serait une extension du temps réel en ajoutant la possibilité de pouvoir se déplacer dans le temps et de revenir à un état précédent de la simulation. Par exemple de retourner de 3 secondes dans le passé de la simulation.

Finalement, nous considérons avoir atteint l'objectif fixé et par conséquent ceci conclu ce rapport.
